==> haskell-dns-4.1.1-66-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dns.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-dns-z-dns-internal
version:              4.1.1
package-name:         dns
lib-name:             dns-internal
id:                   dns-4.1.1-69kcOR21cN8BiZXzMvIo0X-dns-internal
key:                  dns-4.1.1-69kcOR21cN8BiZXzMvIo0X-dns-internal
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.

category:             Network
abi:                  eba55b4c50731d2c7b52695433c6c8fb
exposed-modules:
    Network.DNS.Base32Hex Network.DNS.Decode.Internal
    Network.DNS.Decode.Parsers Network.DNS.Encode.Builders
    Network.DNS.Encode.Internal Network.DNS.Imports Network.DNS.Memo
    Network.DNS.Resolver.Internal Network.DNS.StateBinary
    Network.DNS.Types.Internal Network.DNS.Types.Resolver

import-dirs:          /usr/lib/ghc-9.4.8/site-local/dns-4.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dns-4.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dns-4.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dns
hs-libraries:         HSdns-4.1.1-69kcOR21cN8BiZXzMvIo0X-dns-internal
depends:
    array-0.5.4.0 async-2.2.5-D49NPDHTd69BKX3jfj3d2D
    attoparsec-0.14.4-Lk9m0Bu4xLu6fNaGof6SYp
    auto-update-0.1.6-9PyTb5tNevlKoItIkNoHJP base-4.17.2.1
    base16-bytestring-1.0.2.0-FPGhlHO3pZ4wh96uZmnW2
    base64-bytestring-1.2.1.0-IvMLrkp0izDH09fJ0OSCxo
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-CCVT39CBetAFHWteAF796d
    containers-0.6.7 cryptonite-0.30-LpBMT98fURa7l5laGpurdR
    hourglass-0.2.12-Gk5WWDNcihV9jYp3M8lAAo
    iproute-1.7.15-EWXvYR5zpjnH1LDazmsgjy mtl-2.2.2
    network-3.1.4.0-9GVXDAVmAL58RukaX2Kymu
    psqueues-0.2.8.1-5fSszN7tuaVEtQz7QBISkh

haddock-interfaces:   /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html:         /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dns
version:              4.1.1
visibility:           public
id:                   dns-4.1.1-CPTu3dBV5weKEGfN6pTsMk
key:                  dns-4.1.1-CPTu3dBV5weKEGfN6pTsMk
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.

category:             Network
abi:                  1fc4ce53f0de01ba1d958d43f0f0da5f
exposed:              True
exposed-modules:
    Network.DNS Network.DNS.Decode Network.DNS.Encode Network.DNS.IO
    Network.DNS.Lookup Network.DNS.LookupRaw Network.DNS.Resolver
    Network.DNS.Types Network.DNS.Utils

hidden-modules:       Network.DNS.Transport
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dns-4.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dns-4.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dns-4.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dns
hs-libraries:         HSdns-4.1.1-CPTu3dBV5weKEGfN6pTsMk
depends:
    array-0.5.4.0 async-2.2.5-D49NPDHTd69BKX3jfj3d2D
    attoparsec-0.14.4-Lk9m0Bu4xLu6fNaGof6SYp
    auto-update-0.1.6-9PyTb5tNevlKoItIkNoHJP base-4.17.2.1
    base16-bytestring-1.0.2.0-FPGhlHO3pZ4wh96uZmnW2
    base64-bytestring-1.2.1.0-IvMLrkp0izDH09fJ0OSCxo
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-LpBMT98fURa7l5laGpurdR
    dns-4.1.1-69kcOR21cN8BiZXzMvIo0X-dns-internal
    hourglass-0.2.12-Gk5WWDNcihV9jYp3M8lAAo
    iproute-1.7.15-EWXvYR5zpjnH1LDazmsgjy mtl-2.2.2
    network-3.1.4.0-9GVXDAVmAL58RukaX2Kymu
    psqueues-0.2.8.1-5fSszN7tuaVEtQz7QBISkh

haddock-interfaces:   /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html:         /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dns-4.1.1-67-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dns.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-dns-z-dns-internal
version:              4.1.1
package-name:         dns
lib-name:             dns-internal
id:                   dns-4.1.1-8BOoHGhU4m0Jmrs9wO0Kxd-dns-internal
key:                  dns-4.1.1-8BOoHGhU4m0Jmrs9wO0Kxd-dns-internal
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.

category:             Network
abi:                  51bd5f471375c6b24da75667e066bed5
exposed-modules:
    Network.DNS.Base32Hex Network.DNS.Decode.Internal
    Network.DNS.Decode.Parsers Network.DNS.Encode.Builders
    Network.DNS.Encode.Internal Network.DNS.Imports Network.DNS.Memo
    Network.DNS.Resolver.Internal Network.DNS.StateBinary
    Network.DNS.Types.Internal Network.DNS.Types.Resolver

import-dirs:          /usr/lib/ghc-9.4.8/site-local/dns-4.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dns-4.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dns-4.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dns
hs-libraries:         HSdns-4.1.1-8BOoHGhU4m0Jmrs9wO0Kxd-dns-internal
depends:
    array-0.5.4.0 async-2.2.5-1XOc4BcQD7wBl5bQgVjvBC
    attoparsec-0.14.4-H1Mg1If1sweSExoQVyuwM
    auto-update-0.1.6-8zEg9H9dx2921pqzFTmWX8 base-4.17.2.1
    base16-bytestring-1.0.2.0-5CqdDAFWvdCp6PyRr0Kc1
    base64-bytestring-1.2.1.0-J2XMDRefA2t9Bq5Rx8btPI
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-AQlcRYTbpYHDf3yXCQ8vD
    containers-0.6.7 cryptonite-0.30-4prCd3UqCci26bID4SbsmN
    hourglass-0.2.12-ETz5mXkpv624fnzTteBzXL
    iproute-1.7.15-D1FTxYLNlQ13PlnQzMjLa4 mtl-2.2.2
    network-3.1.4.0-Bla5JD4k8pXGRj5I5yzWl8
    psqueues-0.2.8.1-J4zs305ciACFdk2pOChJSK

haddock-interfaces:   /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html:         /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dns
version:              4.1.1
visibility:           public
id:                   dns-4.1.1-KYmdP8Nn2tW2wHrtKWuzmq
key:                  dns-4.1.1-KYmdP8Nn2tW2wHrtKWuzmq
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.

category:             Network
abi:                  e18753de3d5cfd5cbbffc3ab8985f7e2
exposed:              True
exposed-modules:
    Network.DNS Network.DNS.Decode Network.DNS.Encode Network.DNS.IO
    Network.DNS.Lookup Network.DNS.LookupRaw Network.DNS.Resolver
    Network.DNS.Types Network.DNS.Utils

hidden-modules:       Network.DNS.Transport
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dns-4.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dns-4.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dns-4.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dns
hs-libraries:         HSdns-4.1.1-KYmdP8Nn2tW2wHrtKWuzmq
depends:
    array-0.5.4.0 async-2.2.5-1XOc4BcQD7wBl5bQgVjvBC
    attoparsec-0.14.4-H1Mg1If1sweSExoQVyuwM
    auto-update-0.1.6-8zEg9H9dx2921pqzFTmWX8 base-4.17.2.1
    base16-bytestring-1.0.2.0-5CqdDAFWvdCp6PyRr0Kc1
    base64-bytestring-1.2.1.0-J2XMDRefA2t9Bq5Rx8btPI
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-4prCd3UqCci26bID4SbsmN
    dns-4.1.1-8BOoHGhU4m0Jmrs9wO0Kxd-dns-internal
    hourglass-0.2.12-ETz5mXkpv624fnzTteBzXL
    iproute-1.7.15-D1FTxYLNlQ13PlnQzMjLa4 mtl-2.2.2
    network-3.1.4.0-Bla5JD4k8pXGRj5I5yzWl8
    psqueues-0.2.8.1-J4zs305ciACFdk2pOChJSK

haddock-interfaces:   /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html:         /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
